==> ssp-center-api-0.8.29-20201022.105927-15-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/sdk/TuiaSdkVerifyRecordDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto.sdk;

import cn.com.duiba.tuia.ssp.center.api.dto.BaseDto;

import java.util.List;


public class TuiaSdkVerifyRecordDTO extends BaseDto {

    private static final long serialVersionUID = 8643166950697663333L;

    public static final Integer RELEASE_STATUS_ENABLE = 1;
    public static final Integer RELEASE_STATUS_DISABLE = 0;

    public static final Integer RELEASE_TYPE_ALL = 1;
    public static final Integer RELEASE_TYPE_APP = 2;

    public static final Integer PATCH_RELEASE_TYPE_GRAY = 1; // 灰度
    public static final Integer PATCH_RELEASE_TYPE_FULL = 2; // 全量
    public static final Integer PATCH_RELEASE_TYPE_ROLLBACK = 3; // 回滚
    public static final Integer PATCH_RELEASE_TYPE_STOP = 4; // 回滚

    private Long pluginSetId;

    private String modifier;

    /*0-新建全网版本 1-编辑新建全网版本 2-新建定制版本 3-编辑定制版本 4-删除定制版本*/
    private Integer modifyType;

    private String sdkVersionName;

    private Long sdkVersionCode;

    private Long originPlugins;

    private Long newPlugins;

    private List<Long> originApp;

    private List<Long> newApp;

    private Integer verifyStatus;

    private String pluginSetDesc;

    private Integer releaseType;

    private Integer releaseStatus;

    private Integer patchReleaseStatus;

    private Integer patchReleaseStatusTmp;

    private Integer limitCountCur;

    private Integer limitCountMax;

    // 前端展示用
    private Long pluginVersionCode;
    private String pluginVersionName;
    private String configAppIds;

    public String getPluginSetDesc() {
        return pluginSetDesc;
    }

    public void setPluginSetDesc(String pluginSetDesc) {
        this.pluginSetDesc = pluginSetDesc;
    }

    public Long getPluginSetId() {
        return pluginSetId;
    }

    public void setPluginSetId(Long pluginSetId) {
        this.pluginSetId = pluginSetId;
    }

    public String getModifier() {
        return modifier;
    }

    public void setModifier(String modifier) {
        this.modifier = modifier;
    }

    public Integer getModifyType() {
        return modifyType;
    }

    public void setModifyType(Integer modifyType) {
        this.modifyType = modifyType;
    }

    public String getSdkVersionName() {
        return sdkVersionName;
    }

    public void setSdkVersionName(String sdkVersionName) {
        this.sdkVersionName = sdkVersionName;
    }

    public Long getSdkVersionCode() {
        return sdkVersionCode;
    }

    public void setSdkVersionCode(Long sdkVersionCode) {
        this.sdkVersionCode = sdkVersionCode;
    }

    public Integer getVerifyStatus() {
        return verifyStatus;
    }

    public void setVerifyStatus(Integer verifyStatus) {
        this.verifyStatus = verifyStatus;
    }

    public Long getOriginPlugins() {
        return originPlugins;
    }

    public void setOriginPlugins(Long originPlugins) {
        this.originPlugins = originPlugins;
    }

    public Long getNewPlugins() {
        return newPlugins;
    }

    public void setNewPlugins(Long newPlugins) {
        this.newPlugins = newPlugins;
    }

    public List<Long> getOriginApp() {
        return originApp;
    }

    public void setOriginApp(List<Long> originApp) {
        this.originApp = originApp;
    }

    public List<Long> getNewApp() {
        return newApp;
    }

    public void setNewApp(List<Long> newApp) {
        this.newApp = newApp;
    }

    public Integer getReleaseType() {
        return releaseType;
    }

    public void setReleaseType(Integer releaseType) {
        this.releaseType = releaseType;
    }

    public Integer getReleaseStatus() {
        return releaseStatus;
    }

    public void setReleaseStatus(Integer releaseStatus) {
        this.releaseStatus = releaseStatus;
    }

    public String getConfigAppIds() {
        return configAppIds;
    }

    public void setConfigAppIds(String configAppIds) {
        this.configAppIds = configAppIds;
    }

    public Long getPluginVersionCode() {
        return pluginVersionCode;
    }

    public void setPluginVersionCode(Long pluginVersionCode) {
        this.pluginVersionCode = pluginVersionCode;
    }

    public String getPluginVersionName() {
        return pluginVersionName;
    }

    public void setPluginVersionName(String pluginVersionName) {
        this.pluginVersionName = pluginVersionName;
    }

    public Integer getPatchReleaseStatus() {
        return patchReleaseStatus;
    }

    public void setPatchReleaseStatus(Integer patchReleaseStatus) {
        this.patchReleaseStatus = patchReleaseStatus;
    }

    public Integer getPatchReleaseStatusTmp() {
        return patchReleaseStatusTmp;
    }

    public void setPatchReleaseStatusTmp(Integer patchReleaseStatusTmp) {
        this.patchReleaseStatusTmp = patchReleaseStatusTmp;
    }

    public Integer getLimitCountCur() {
        return limitCountCur;
    }

    public void setLimitCountCur(Integer limitCountCur) {
        this.limitCountCur = limitCountCur;
    }

    public Integer getLimitCountMax() {
        return limitCountMax;
    }

    public void setLimitCountMax(Integer limitCountMax) {
        this.limitCountMax = limitCountMax;
    }
}

==> ssp-center-api-0.8.29-20201023.062803-19-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/sdk/TuiaSdkVerifyRecordDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto.sdk;

import cn.com.duiba.tuia.ssp.center.api.dto.BaseDto;

import java.util.List;


public class TuiaSdkVerifyRecordDTO extends BaseDto {

    private static final long serialVersionUID = 8643166950697663333L;

    public static final Integer RELEASE_STATUS_ENABLE = 1;
    public static final Integer RELEASE_STATUS_DISABLE = 0;

    public static final Integer RELEASE_TYPE_ALL = 1;
    public static final Integer RELEASE_TYPE_APP = 2;

    public static final Integer PATCH_RELEASE_TYPE_GRAY = 1; // 灰度
    public static final Integer PATCH_RELEASE_TYPE_FULL = 2; // 全量
    public static final Integer PATCH_RELEASE_TYPE_ROLLBACK = 3; // 回滚
    public static final Integer PATCH_RELEASE_TYPE_STOP = 4; // 回滚

    private Long pluginSetId;

    private String modifier;

    /*0-新建全网版本 1-编辑新建全网版本 2-新建定制版本 3-编辑定制版本 4-删除定制版本*/
    private Integer modifyType;

    private String sdkVersionName;

    private Long sdkVersionCode;

    private Long originPlugins;

    private Long newPlugins;

    private List<Long> originApp;

    private List<Long> newApp;

    private Integer verifyStatus;

    private String pluginSetDesc;

    private Integer releaseType;

    private Integer releaseStatus;

    private Integer patchReleaseStatus;

    private Integer patchReleaseStatusTmp;

    private Integer limitCountCur;

    private Integer limitCountMax;

    // 前端展示用
    private Long pluginVersionCode;
    private String pluginVersionName;
    private String configAppIds;
    private Integer rollbackShow = 0;//是否显示回滚操作，0=关闭、1=开启

    public String getPluginSetDesc() {
        return pluginSetDesc;
    }

    public void setPluginSetDesc(String pluginSetDesc) {
        this.pluginSetDesc = pluginSetDesc;
    }

    public Long getPluginSetId() {
        return pluginSetId;
    }

    public void setPluginSetId(Long pluginSetId) {
        this.pluginSetId = pluginSetId;
    }

    public String getModifier() {
        return modifier;
    }

    public void setModifier(String modifier) {
        this.modifier = modifier;
    }

    public Integer getModifyType() {
        return modifyType;
    }

    public void setModifyType(Integer modifyType) {
        this.modifyType = modifyType;
    }

    public String getSdkVersionName() {
        return sdkVersionName;
    }

    public void setSdkVersionName(String sdkVersionName) {
        this.sdkVersionName = sdkVersionName;
    }

    public Long getSdkVersionCode() {
        return sdkVersionCode;
    }

    public void setSdkVersionCode(Long sdkVersionCode) {
        this.sdkVersionCode = sdkVersionCode;
    }

    public Integer getVerifyStatus() {
        return verifyStatus;
    }

    public void setVerifyStatus(Integer verifyStatus) {
        this.verifyStatus = verifyStatus;
    }

    public Long getOriginPlugins() {
        return originPlugins;
    }

    public void setOriginPlugins(Long originPlugins) {
        this.originPlugins = originPlugins;
    }

    public Long getNewPlugins() {
        return newPlugins;
    }

    public void setNewPlugins(Long newPlugins) {
        this.newPlugins = newPlugins;
    }

    public List<Long> getOriginApp() {
        return originApp;
    }

    public void setOriginApp(List<Long> originApp) {
        this.originApp = originApp;
    }

    public List<Long> getNewApp() {
        return newApp;
    }

    public void setNewApp(List<Long> newApp) {
        this.newApp = newApp;
    }

    public Integer getReleaseType() {
        return releaseType;
    }

    public void setReleaseType(Integer releaseType) {
        this.releaseType = releaseType;
    }

    public Integer getReleaseStatus() {
        return releaseStatus;
    }

    public void setReleaseStatus(Integer releaseStatus) {
        this.releaseStatus = releaseStatus;
    }

    public String getConfigAppIds() {
        return configAppIds;
    }

    public void setConfigAppIds(String configAppIds) {
        this.configAppIds = configAppIds;
    }

    public Long getPluginVersionCode() {
        return pluginVersionCode;
    }

    public void setPluginVersionCode(Long pluginVersionCode) {
        this.pluginVersionCode = pluginVersionCode;
    }

    public String getPluginVersionName() {
        return pluginVersionName;
    }

    public void setPluginVersionName(String pluginVersionName) {
        this.pluginVersionName = pluginVersionName;
    }

    public Integer getPatchReleaseStatus() {
        return patchReleaseStatus;
    }

    public void setPatchReleaseStatus(Integer patchReleaseStatus) {
        this.patchReleaseStatus = patchReleaseStatus;
    }

    public Integer getPatchReleaseStatusTmp() {
        return patchReleaseStatusTmp;
    }

    public void setPatchReleaseStatusTmp(Integer patchReleaseStatusTmp) {
        this.patchReleaseStatusTmp = patchReleaseStatusTmp;
    }

    public Integer getLimitCountCur() {
        return limitCountCur;
    }

    public void setLimitCountCur(Integer limitCountCur) {
        this.limitCountCur = limitCountCur;
    }

    public Integer getLimitCountMax() {
        return limitCountMax;
    }

    public void setLimitCountMax(Integer limitCountMax) {
        this.limitCountMax = limitCountMax;
    }

    public Integer getRollbackShow() {
        return rollbackShow;
    }

    public void setRollbackShow(Integer rollbackShow) {
        this.rollbackShow = rollbackShow;
    }
}
